## 4.21.0.0 (2023-07-11)

[stubsabot] Bump braintree to 4.21.* (#10433)

Release: https://pypi.org/pypi/braintree/4.21.0
Homepage: https://developer.paypal.com/braintree/docs/reference/overview

## 4.20.0.0 (2023-05-23)

[stubsabot] Bump braintree to 4.20.* (#10198)

Release: https://pypi.org/pypi/braintree/4.20.0
Homepage: https://developer.paypal.com/braintree/docs/reference/overview

## 4.19.0.1 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 4.19.0.0 (2023-04-07)

[stubsabot] Bump braintree to 4.19.* (#10017)

Release: https://pypi.org/pypi/braintree/4.19.0
Homepage: https://developer.paypal.com/braintree/docs/reference/overview

## 4.18.0.3 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 4.18.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 4.18.0.1 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 4.18.0.0 (2023-01-12)

[stubsabot] Bump braintree to 4.18.* (#9502)

Release: https://pypi.org/pypi/braintree/4.18.0
Homepage: https://developer.paypal.com/braintree/docs/reference/overview

## 4.17.0.1 (2022-11-09)

Annotate known magic-method return types (#9131)

## 4.17.0.0 (2022-10-05)

[stubsabot] Bump braintree to 4.17.* (#8847)

Release: https://pypi.org/pypi/braintree/4.17.0
Homepage: https://developer.paypal.com/braintree/docs/reference/overview

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 4.16.0 (2022-07-29)

Bump braintree to 4.16.* (#8433)

Resolves #8431

## 4.15.0 (2022-06-14)

[stubsabot] Bump braintree to 4.15.* (#8080)

Co-authored-by: hauntsaninja <>

## 4.11.4 (2022-03-06)

Upgrade to stubtest with dunder pos only reverted (#7442)

## 4.11.3 (2022-01-31)

Upgrade black version (#7089)

## 4.11.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

